import React, { CSSProperties } from 'react';

/**
 * @license qrcode.react
 * Copyright (c) Paul O'Shannessy
 * SPDX-License-Identifier: ISC
 */

declare type QRProps = {
    value: string;
    size: number;
    level: string;
    bgColor: string;
    fgColor: string;
    style?: CSSProperties;
    includeMargin: boolean;
    imageSettings?: {
        src: string;
        height: number;
        width: number;
        excavate: boolean;
        x?: number;
        y?: number;
    };
};
declare type QRPropsCanvas = QRProps & React.CanvasHTMLAttributes<HTMLCanvasElement>;
declare type QRPropsSVG = QRProps & React.SVGProps<SVGSVGElement>;
declare function QRCodeCanvas(props: QRPropsCanvas): JSX.Element;
declare namespace QRCodeCanvas {
    var defaultProps: {
        size: number;
        level: string;
        bgColor: string;
        fgColor: string;
        includeMargin: boolean;
    };
}
declare function QRCodeSVG(props: QRPropsSVG): JSX.Element;
declare namespace QRCodeSVG {
    var defaultProps: {
        size: number;
        level: string;
        bgColor: string;
        fgColor: string;
        includeMargin: boolean;
    };
}
declare type RootProps = (QRPropsSVG & {
    renderAs: 'svg';
}) | (QRPropsCanvas & {
    renderAs: 'canvas';
});
declare const QRCode: {
    (props: RootProps): JSX.Element;
    defaultProps: {
        size: number;
        level: string;
        bgColor: string;
        fgColor: string;
        includeMargin: boolean;
        renderAs: string;
    };
};

export { QRCodeCanvas, QRCodeSVG, QRCode as default };
